Class: Aws::CodeStarNotifications::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodeStarNotifications::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codestarnotifications/client.rb,
sig/client.rbs
Overview
An API client for CodeStarNotifications. To construct a client, you need to configure a :region and :credentials.
client = Aws::CodeStarNotifications::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateNotificationRuleResponseSuccess, _DeleteNotificationRuleResponseSuccess, _DeleteTargetResponseSuccess, _DescribeNotificationRuleResponseSuccess, _ListEventTypesResponseSuccess, _ListNotificationRulesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTargetsResponseSuccess, _SubscribeResponseSuccess, _TagResourceResponseSuccess, _UnsubscribeResponseSuccess, _UntagResourceResponseSuccess, _UpdateNotificationRuleResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_notification_rule(params = {}) ⇒ Types::CreateNotificationRuleResult
Creates a notification rule for a resource.
-
#delete_notification_rule(params = {}) ⇒ Types::DeleteNotificationRuleResult
Deletes a notification rule for a resource.
-
#delete_target(params = {}) ⇒ Struct
Deletes a specified target for notifications.
-
#describe_notification_rule(params = {}) ⇒ Types::DescribeNotificationRuleResult
Returns information about a specified notification rule.
-
#list_event_types(params = {}) ⇒ Types::ListEventTypesResult
Returns information about the event types available for configuring notifications.
-
#list_notification_rules(params = {}) ⇒ Types::ListNotificationRulesResult
Returns a list of the notification rules for an Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Returns a list of the tags associated with a notification rule.
-
#list_targets(params = {}) ⇒ Types::ListTargetsResult
Returns a list of the notification rule targets for an Amazon Web Services account.
-
#subscribe(params = {}) ⇒ Types::SubscribeResult
Creates an association between a notification rule and an Amazon Q Developer in chat applications topic or Amazon Q Developer in chat applications client so that the associated target can receive notifications when the events described in the rule are triggered.
-
#tag_resource(params = {}) ⇒ Types::TagResourceResult
Associates a set of provided tags with a notification rule.
-
#unsubscribe(params = {}) ⇒ Types::UnsubscribeResult
Removes an association between a notification rule and an Amazon Q Developer in chat applications topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered.
-
#untag_resource(params = {}) ⇒ Struct
Removes the association between one or more provided tags and a notification rule.
-
#update_notification_rule(params = {}) ⇒ Struct
Updates a notification rule for a resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-codestarnotifications/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1127 1128 1129 |
# File 'lib/aws-sdk-codestarnotifications/client.rb', line 1127 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1130 1131 1132 |
# File 'lib/aws-sdk-codestarnotifications/client.rb', line 1130 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/aws-sdk-codestarnotifications/client.rb', line 1100 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodeStarNotifications') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codestarnotifications' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#create_notification_rule(params = {}) ⇒ Types::CreateNotificationRuleResult
Creates a notification rule for a resource. The rule specifies the events you want notifications about and the targets (such as Amazon Q Developer in chat applications topics or Amazon Q Developer in chat applications clients configured for Slack) where you want to receive them.
86 |
# File 'sig/client.rbs', line 86
def create_notification_rule: (
|
#delete_notification_rule(params = {}) ⇒ Types::DeleteNotificationRuleResult
Deletes a notification rule for a resource.
108 |
# File 'sig/client.rbs', line 108
def delete_notification_rule: (
|
#delete_target(params = {}) ⇒ Struct
Deletes a specified target for notifications.
117 |
# File 'sig/client.rbs', line 117
def delete_target: (
|
#describe_notification_rule(params = {}) ⇒ Types::DescribeNotificationRuleResult
Returns information about a specified notification rule.
138 |
# File 'sig/client.rbs', line 138
def describe_notification_rule: (
|
#list_event_types(params = {}) ⇒ Types::ListEventTypesResult
Returns information about the event types available for configuring notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
149 |
# File 'sig/client.rbs', line 149
def list_event_types: (
|
#list_notification_rules(params = {}) ⇒ Types::ListNotificationRulesResult
Returns a list of the notification rules for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
167 |
# File 'sig/client.rbs', line 167
def list_notification_rules: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Returns a list of the tags associated with a notification rule.
184 |
# File 'sig/client.rbs', line 184
def list_tags_for_resource: (
|
#list_targets(params = {}) ⇒ Types::ListTargetsResult
Returns a list of the notification rule targets for an Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
195 |
# File 'sig/client.rbs', line 195
def list_targets: (
|
#subscribe(params = {}) ⇒ Types::SubscribeResult
Creates an association between a notification rule and an Amazon Q Developer in chat applications topic or Amazon Q Developer in chat applications client so that the associated target can receive notifications when the events described in the rule are triggered.
212 |
# File 'sig/client.rbs', line 212
def subscribe: (
|
#tag_resource(params = {}) ⇒ Types::TagResourceResult
Associates a set of provided tags with a notification rule.
227 |
# File 'sig/client.rbs', line 227
def tag_resource: (
|
#unsubscribe(params = {}) ⇒ Types::UnsubscribeResult
Removes an association between a notification rule and an Amazon Q Developer in chat applications topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered.
238 |
# File 'sig/client.rbs', line 238
def unsubscribe: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the association between one or more provided tags and a notification rule.
248 |
# File 'sig/client.rbs', line 248
def untag_resource: (
|
#update_notification_rule(params = {}) ⇒ Struct
Updates a notification rule for a resource. You can change the events that trigger the notification rule, the status of the rule, and the targets that receive the notifications.
258 |
# File 'sig/client.rbs', line 258
def update_notification_rule: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1120 1121 1122 |
# File 'lib/aws-sdk-codestarnotifications/client.rb', line 1120 def waiter_names [] end |